betty.gramps.error module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.gramps.error module

Provide Gramps error handling utilities.

exception betty.gramps.error.GrampsError

  Bases: `Exception`

  A Gramps API error.

exception betty.gramps.error.UserFacingGrampsError

  Bases: `GrampsError`, `UserFacingError`

  A user-facing Gramps API error.